@@ -1,8 +1,12 @@
-import typing
-import matplotlib.axes
 import cartopy.mpl.geoaxes
-import xarray
+from itertools import chain
+import matplotlib.axes
+import metpy.calc as mpcalc
+from pint import Quantity
+from metpy.units import units
 import numpy as np
+import typing
+import xarray
 
 
 def set_tick_direction_spine_visibility(ax,
@@ -1112,3 +1116,70 @@ def set_vector_density(data: xarray.DataArray,
                        lon=slice(None, None, lon_every))
 
         return ds
+
+
+def get_skewt_vars(p: Quantity, tc: Quantity, tdc: Quantity,
+                   pro: Quantity) -> str:
+    """This function processes the dataset values and returns a string element
+    which can be used as a subtitle to replicate the styles of NCL Skew-T
+    Diagrams.
+
+    Parameters
+    ----------
+    p : :class:`pint.Quantity`
+        Pressure level input from dataset
+    tc : :class:`pint.Quantity`
+        Temperature for parcel from dataset
+    tdc : :class:`pint.Quantity`
+        Dew point temperature for parcel from dataset
+    pro : :class:`pint.Quantity`
+        Parcel profile temperature converted to degC
+    Returns
+    -------
+    joined : :class:`str`
+        A string element with the format "Plcl=<value> Tlcl[C]=<value> Shox=<value> Pwat[cm]=<value> Cape[J]=<value>" where:
+        - Cape  -  Convective Available Potential Energy [J]
+        - Pwat  -  Precipitable Water [cm]
+        - Shox  -  Showalter Index (stability)
+        - Plcl  -  Pressure of the lifting condensation level [hPa]
+        - Tlcl  -  Temperature at the lifting condensation level [C]
+    See Also
+    --------
+    Related NCL Functions:
+    `skewT_PlotData <https://www.ncl.ucar.edu/Document/Functions/Skewt_func/skewT_PlotData.shtml>`_,
+    `skewt_BackGround <https://www.ncl.ucar.edu/Document/Functions/Skewt_func/skewT_BackGround.shtml>`_
+    """
+
+    # CAPE
+    cape = mpcalc.cape_cin(p, tc, tdc, pro)
+    cape = cape[0].magnitude
+
+    # Precipitable Water
+    pwat = mpcalc.precipitable_water(p, tdc)
+    pwat = (pwat.magnitude / 10) * units.cm  # Convert mm to cm
+    pwat = pwat.magnitude
+
+    # Pressure and temperature of lcl
+    lcl = mpcalc.lcl(p[0], tc[0], tdc[0])
+    plcl = lcl[0].magnitude
+    tlcl = lcl[1].magnitude
+
+    # Showalter index
+    shox = mpcalc.showalter_index(p, tc, tdc)
+    shox = shox[0].magnitude
+
+    # Place calculated values in iterable list
+    vals = [plcl, tlcl, shox, pwat, cape]
+    vals = np.round(vals).astype(int)
+
+    # Define variable names for calculated values
+    names = ['Plcl=', 'Tlcl[C]=', 'Shox=', 'Pwat[cm]=', 'Cape[J]=']
+
+    # Combine the list of values with their corresponding labels
+    lst = list(chain.from_iterable(zip(names, vals)))
+    lst = map(str, lst)
+
+    # Create one large string for later plotting use
+    joined = ' '.join(lst)
+
+    return joined
